@@ -2,20 +2,18 @@
 
 from __future__ import annotations
 
-from typing import Dict, Tuple
+from typing import TYPE_CHECKING
 
-from glove80.base import LayerSpec
-from glove80.layouts.layers import Token, _rows_to_layer_spec
+from glove80.layouts.layers import Token, rows_to_layer_spec
 
-LayerRows = Tuple[Tuple[Token, ...], ...]
+if TYPE_CHECKING:
+    from glove80.base import LayerSpec
+
+LayerRows = tuple[tuple[Token, ...], ...]
 
 
-def _layer(rows: LayerRows) -> LayerSpec:
-    return _rows_to_layer_spec(rows)
-
-
-ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
-    "Enthium": _layer(
+ALPHA_LAYER_SPECS: dict[str, LayerSpec] = {
+    "Enthium": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -113,9 +111,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "Engrammer": _layer(
+    "Engrammer": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -213,9 +211,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "Engram": _layer(
+    "Engram": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -313,9 +311,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "Dvorak": _layer(
+    "Dvorak": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -413,9 +411,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "Colemak": _layer(
+    "Colemak": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -513,9 +511,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "QWERTY": _layer(
+    "QWERTY": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -613,9 +611,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "ColemakDH": _layer(
+    "ColemakDH": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -713,9 +711,9 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "PG_DN",
                 "&magic",
             ),
-        )
+        ),
     ),
-    "Typing": _layer(
+    "Typing": rows_to_layer_spec(
         (
             (
                 "&trans",
@@ -813,6 +811,6 @@ ALPHA_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "&trans",
                 "&trans",
             ),
-        )
+        ),
     ),
 }
