@@ -2,20 +2,18 @@
 
 from __future__ import annotations
 
-from typing import Dict, Tuple
+from typing import TYPE_CHECKING
 
-from glove80.base import LayerSpec
-from glove80.layouts.layers import Token, _rows_to_layer_spec
+from glove80.layouts.layers import Token, rows_to_layer_spec
 
-LayerRows = Tuple[Tuple[Token, ...], ...]
+if TYPE_CHECKING:
+    from glove80.base import LayerSpec
+
+LayerRows = tuple[tuple[Token, ...], ...]
 
 
-def _layer(rows: LayerRows) -> LayerSpec:
-    return _rows_to_layer_spec(rows)
-
-
-UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
-    "Cursor": _layer(
+UTILITY_LAYER_SPECS: dict[str, LayerSpec] = {
+    "Cursor": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -113,9 +111,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 ("Custom", "&kp _C(H)"),
                 ("Custom", "&kp _C(K)"),
             ),
-        )
+        ),
     ),
-    "Number": _layer(
+    "Number": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -213,9 +211,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "RPAR",
                 "AT",
             ),
-        )
+        ),
     ),
-    "Function": _layer(
+    "Function": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -313,9 +311,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "C_BRI_MIN",
                 "C_BRI_AUTO",
             ),
-        )
+        ),
     ),
-    "Emoji": _layer(
+    "Emoji": rows_to_layer_spec(
         (
             (
                 ("Custom", "&emoji_cloudy"),
@@ -413,9 +411,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 ("Custom", "&emoji_cross"),
                 ("Custom", "&emoji_question"),
             ),
-        )
+        ),
     ),
-    "World": _layer(
+    "World": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -513,9 +511,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "&none",
                 "&none",
             ),
-        )
+        ),
     ),
-    "Symbol": _layer(
+    "Symbol": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -613,9 +611,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "&none",
                 "&none",
             ),
-        )
+        ),
     ),
-    "System": _layer(
+    "System": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -713,9 +711,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "CAPS",
                 ("Custom", "&kp _POWER"),
             ),
-        )
+        ),
     ),
-    "Gaming": _layer(
+    "Gaming": rows_to_layer_spec(
         (
             (
                 "ESC",
@@ -813,9 +811,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "EQUAL",
                 "GRAVE",
             ),
-        )
+        ),
     ),
-    "Factory": _layer(
+    "Factory": rows_to_layer_spec(
         (
             (
                 "F1",
@@ -913,9 +911,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "RBKT",
                 "PG_DN",
             ),
-        )
+        ),
     ),
-    "Lower": _layer(
+    "Lower": rows_to_layer_spec(
         (
             (
                 "&none",
@@ -1013,9 +1011,9 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "&none",
                 "&none",
             ),
-        )
+        ),
     ),
-    "Magic": _layer(
+    "Magic": rows_to_layer_spec(
         (
             (
                 ("&bt", "BT_CLR"),
@@ -1113,6 +1111,6 @@ UTILITY_LAYER_SPECS: Dict[str, LayerSpec] = {
                 "&none",
                 "&none",
             ),
-        )
+        ),
     ),
 }
