@@ -12,5 +12,5 @@ def _canonical_layer(variant: str, loader):
 
 
 @pytest.mark.parametrize("variant", TAILORKEY_VARIANTS)
-def test_gaming_layer(variant, load_tailorkey_variant):
+def test_gaming_layer(variant, load_tailorkey_variant) -> None:
     assert build_gaming_layer(variant) == _canonical_layer(variant, load_tailorkey_variant)
