@@ -2,20 +2,19 @@ import json
 
 import pytest
 
-from glove80.metadata import load_metadata
 from glove80 import build_layout as build_family_layout
-
+from glove80.metadata import load_metadata
+from tests.assertions import assert_layout_equal
 
 TAILORKEY_VARIANTS = sorted(load_metadata(layout="tailorkey").keys())
 
 
 @pytest.mark.parametrize("variant", TAILORKEY_VARIANTS)
-def test_generated_files_match_canonical_source(variant, tailorkey_metadata, repo_root):
+def test_generated_files_match_canonical_source(variant, tailorkey_metadata, repo_root) -> None:
     """Each release JSON must match its canonical source exactly."""
-
     meta = tailorkey_metadata[variant]
     source_path = repo_root / meta["output"]
     expected = json.loads(source_path.read_text())
 
     built = build_family_layout("tailorkey", variant)
-    assert built == expected
+    assert_layout_equal(built, expected, label=f"tailorkey:{variant}")
