@@ -12,5 +12,5 @@ def _load_canonical_layer(variant: str, loader):
 
 
 @pytest.mark.parametrize("variant", TAILORKEY_VARIANTS)
-def test_symbol_layer_matches_canonical(variant, load_tailorkey_variant):
+def test_symbol_layer_matches_canonical(variant, load_tailorkey_variant) -> None:
     assert build_symbol_layer(variant) == _load_canonical_layer(variant, load_tailorkey_variant)
